Crate salus_agent

Crate salus_agent 

salus login agent

Modules

keystore
Storage for enrolled share sets, shared by the client (which enrolls and forgets sets) and the agent (which loads and unseals them).

Functions

run_agent
Run the salus login agent to completion, returning the process exit code.